summaryrefslogtreecommitdiff
path: root/src/udev
diff options
context:
space:
mode:
authorSean McGovern <gseanmcg@gmail.com>2013-06-26 14:15:09 -0400
committerAnthony G. Basile <blueness@gentoo.org>2013-06-26 14:15:52 -0400
commit983cecd7952790c2d80fe77cc429c4fa762d990d (patch)
tree6816cdca60d787bb472638a78396bf84f1a7346f /src/udev
parent98cddf4cb7c006437ad06dd239f09af5ef71e353 (diff)
udev: handle network controllers in nonstandard domains
Onboard network controllers are not always on PCI domain 0. [Kay: use int instead of long, add [P] to slot naming, remove sysname var] Signed-off-by: Anthony G. Basile <blueness@gentoo.org>
Diffstat (limited to 'src/udev')
-rw-r--r--src/udev/udev-builtin-net_id.c20
1 files changed, 15 insertions, 5 deletions
diff --git a/src/udev/udev-builtin-net_id.c b/src/udev/udev-builtin-net_id.c
index 2f38ef0969..37ae710ea9 100644
--- a/src/udev/udev-builtin-net_id.c
+++ b/src/udev/udev-builtin-net_id.c
@@ -35,13 +35,16 @@
* o<index> -- on-board device index number
* s<slot>[f<function>][d<dev_id>] -- hotplug slot index number
* x<MAC> -- MAC address
* p<bus>s<slot>[f<function>][d<dev_id>] -- PCI geographical location
* p<bus>s<slot>[f<function>][u<port>][..][c<config>][i<interface>]
* -- USB port number chain
*
* All multi-function PCI devices will carry the [f<function>] number in the
* device name, including the function 0 device.
*
+ * When using PCI geography, The PCI domain is only prepended when it is not 0.
+ *
* For USB devices the full chain of port numbers of hubs is composed. If the
* name gets longer than the maximum number of 15 characters, the name is not
* exported.
@@ -162,6 +165,7 @@ out:
static int dev_pci_slot(struct udev_device *dev, struct netnames *names) {
struct udev *udev = udev_device_get_udev(names->pcidev);
+ unsigned int domain;
unsigned int bus;
unsigned int slot;
unsigned int func;
@@ -177,7 +181,7 @@ static int dev_pci_slot(struct udev_device *dev, struct netnames *names) {
int hotplug_slot = 0;
int err = 0;
- if (sscanf(udev_device_get_sysname(names->pcidev), "0000:%x:%x.%d", &bus, &slot, &func) != 3)
+ if (sscanf(udev_device_get_sysname(names->pcidev), "%x:%x:%x.%d", &domain, &bus, &slot, &func) != 4)
return -ENOENT;
/* kernel provided multi-device index */
@@ -187,7 +191,10 @@ static int dev_pci_slot(struct udev_device *dev, struct netnames *names) {
/* compose a name based on the raw kernel's PCI bus, slot numbers */
s = names->pci_path;
- l = util_strpcpyf(&s, sizeof(names->pci_path), "p%ds%d", bus, slot);
+ l = sizeof(names->pci_path);
+ if (domain > 0)
+ l = util_strpcpyf(&s, l, "P%d", domain);
+ l = util_strpcpyf(&s, l, "p%ds%d", bus, slot);
if (func > 0 || is_pci_multifunction(names->pcidev))
l = util_strpcpyf(&s, l, "f%d", func);
if (dev_id > 0)
@@ -235,7 +242,10 @@ static int dev_pci_slot(struct udev_device *dev, struct netnames *names) {
if (hotplug_slot > 0) {
s = names->pci_slot;
- l = util_strpcpyf(&s, sizeof(names->pci_slot), "s%d", hotplug_slot);
+ l = sizeof(names->pci_slot);
+ if (domain > 0)
+ l = util_strpcpyf(&s, l, "P%d", domain);
+ l = util_strpcpyf(&s, l, "s%d", hotplug_slot);
if (func > 0 || is_pci_multifunction(names->pcidev))
l = util_strpcpyf(&s, l, "f%d", func);
if (dev_id > 0)
@@ -35,13 +35,16 @@
* s<slot>[f<function>][d<dev_id>] -- hotplug slot index number
* x<MAC> -- MAC address
- * p<bus>s<slot>[f<function>][d<dev_id>] -- PCI geographical location
- * p<bus>s<slot>[f<function>][u<port>][..][c<config>][i<interface>]
+ * [P<domain>]p<bus>s<slot>[f<function>][d<dev_id>]
+ * -- PCI geographical location
+ * [P<domain>]p<bus>s<slot>[f<function>][u<port>][..][c<config>][i<interface>]
* -- USB port number chain
*